﻿'Project: StreamWriter
'Author: Anthony DePinto 
'Date: Fall 2014
'Description: Description of the form being created 
'
Imports System.IO ' using classes from this namespace

Public Class CreateAccounts
    Dim AccountStreamWriter As StreamWriter ' writes data to text file

    ' create a new file in which accounts can be stored
    Private Sub NewToolStripMenuItem_Click(sender As Object,
       e As EventArgs) Handles NewToolStripMenuItem.Click
        Dim FileDialogResult As DialogResult ' stores result of Save dialog
        Dim FilenameString As String ' name of file to save data

        CloseFile() ' ensure that any prior file is closed

        ' display dialog so user can choose the name of the file to save
        Using FileSaveFileDialog As New SaveFileDialog()
            FileDialogResult = FileSaveFileDialog.ShowDialog()
            FilenameString = FileSaveFileDialog.FileName ' get specified file name
        End Using ' automatic call to fileChooser.Dispose() occurs here

        ' if user did not click Cancel
        If FileDialogResult <> Windows.Forms.DialogResult.Cancel Then
            Try
                ' open or create file for writing
                AccountStreamWriter = New StreamWriter(FilenameString, True)

                ' enable controls
                CloseToolStripMenuItem.Enabled = True
                addAccountButton.Enabled = True
                accountNumberTextBox.Enabled = True
                firstNameTextBox.Enabled = True
                lastNameTextBox.Enabled = True
                balanceTextBox.Enabled = True
            Catch ex As IOException
                MessageBox.Show("Error Opening File", "Error",
                   MessageBoxButtons.OK, MessageBoxIcon.Error)
            End Try
        End If
    End Sub ' NewToolStripMenuItem_Click

    ' add an account to the file
    Private Sub addAccountButton_Click(sender As Object,
       e As EventArgs) Handles addAccountButton.Click
        Dim AccountNumberInteger As Integer

        ' determine whether TextBox account field is empty
        If accountNumberTextBox.Text <> String.Empty Then
            ' try to store record to file
            Try
                ' get account number
                AccountNumberInteger = Convert.ToInt32(accountNumberTextBox.Text)

                If AccountNumberInteger > 0 Then ' valid account number?
                    ' write record data to file separating fields by commas
                    AccountStreamWriter.WriteLine(AccountNumberInteger.ToString & "," &
                       firstNameTextBox.Text & "," &
                       lastNameTextBox.Text & "," &
                       Convert.ToDecimal(balanceTextBox.Text).ToString)
                Else
                    MessageBox.Show("Invalid Account Number", "Error",
                       MessageBoxButtons.OK, MessageBoxIcon.Error)
                End If
            Catch ex As IOException
                MessageBox.Show("Error Writing to File", "Error",
                   MessageBoxButtons.OK, MessageBoxIcon.Error)
            Catch ex As FormatException
                MessageBox.Show("Invalid account number or balance",
                   "Format Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
            End Try
        End If

        accountNumberTextBox.Clear()
        firstNameTextBox.Clear()
        lastNameTextBox.Clear()
        balanceTextBox.Clear()
        accountNumberTextBox.Focus()
    End Sub ' addAccountButton_Click

    ' close the currently open file and disable controls
    Private Sub CloseToolStripMenuItem_Click(sender As Object,
       e As EventArgs) Handles CloseToolStripMenuItem.Click

        CloseFile() ' close currently open file

        CloseToolStripMenuItem.Enabled = False
        addAccountButton.Enabled = False
        accountNumberTextBox.Enabled = False
        firstNameTextBox.Enabled = False
        lastNameTextBox.Enabled = False
        balanceTextBox.Enabled = False
    End Sub ' CloseToolStripMenuItem_Click

    ' exit the application
    Private Sub ExitToolStripMenuItem_Click(sender As Object,
       e As EventArgs) Handles ExitToolStripMenuItem.Click

        CloseFile() ' close the file before terminating application

        Me.Close()

    End Sub ' ExitToolStripMenuItem_Click

    ' close the file
    Sub CloseFile()
        If AccountStreamWriter IsNot Nothing Then
            Try
                AccountStreamWriter.Close() ' close StreamWriter
            Catch ex As IOException
                MessageBox.Show("Error closing file", "Error",
                   MessageBoxButtons.OK, MessageBoxIcon.Error)
            End Try
        End If
    End Sub ' CloseFile
End Class ' CreateAccounts
